@@ -1,15 +1,10 @@
-__version__ = '0.0.1'
+__version__ = '0.1.0'
 
 from docutils.parsers.rst import directives, Directive
 from docutils import nodes
-from sphinx.util.osutil import copyfile
 from sphinx.directives.code import CodeBlock
 
 import os
-try:
-    import importlib.resources as resources
-except ImportError:
-    import importlib_resources as resources
 
 
 CSS_FILE = "code-tabs.css"
@@ -66,26 +61,13 @@ def depart_tab_html(self, node):
 
 
 def add_assets(app):
+    app.config.html_static_path.append(os.path.dirname(__file__))
     app.add_css_file(CSS_FILE)
     app.add_js_file(JS_FILE)
 
 
-def copy_assets(app, exception):
-    if app.builder.name == "html" and not exception:
-        static_dir = os.path.join(app.builder.outdir, "_static")
-        copy_asset(CSS_FILE, static_dir)
-        copy_asset(JS_FILE, static_dir)
-
-
-def copy_asset(basename, outdir):
-    dest = os.path.join(outdir, basename)
-    with resources.path(__package__, basename) as source:
-        copyfile(str(source), dest)
-
-
 def setup(app):
     app.add_node(Tab, html=(visit_tab_html, depart_tab_html))
     app.add_directive("code-tabs", CodeTabs)
     app.add_directive("code-tab", CodeTab)
     app.connect("builder-inited", add_assets)
-    app.connect("build-finished", copy_assets)
